from weasyprint import CSS, HTML
from weasyprint.fonts import FontConfiguration
from django.core.files import File
from django.template.loader import render_to_string
import os
#Django==3.0.7
#WeasyPrint==52.5
def htmlToPdf(media_root_url,file_name,template_src,context_dict={}):
    ''' 
        This function return file with parameter media root url ,file name, template src with differents variables in context_dict
    
    '''
    html_content = render_to_string(template_src, context_dict) # render with dynamic value        
    font_config = FontConfiguration()
    html = HTML(string=html_content)
    css = CSS(string='@page { size: A3; margin: 1cm }',font_config=font_config)
    path_file = os.path.join(media_root_url,str(file_name)+".pdf")
    html.write_pdf(path_file, stylesheets=[css])
    f = open(path_file, "rb")
    new_file = File(f)
    return new_file

def htmlToPdfWithCss(media_root_url,file_name,template_src,context_dict={},stylesheet='@page { size: A3; margin: 850px }'):
    ''' 
        This function return file with parameter media root url ,file name, stylesheet css ,and template src with differents variables in context_dict
    
    '''
    html_content = render_to_string(template_src, context_dict) # render with dynamic value        
    font_config = FontConfiguration()
    html = HTML(string=html_content)
    css = CSS(string=stylesheet,font_config=font_config)
    path_file = os.path.join(media_root_url,str(file_name)+".pdf")
    html.write_pdf(path_file, stylesheets=[css])
    f = open(path_file, "rb")
    new_file = File(f)
    return new_file


"""
Your licence goes here
"""

from setuptools import setup, find_packages

# See note below for more information about classifiers
def readme():
    with open('README.md') as f:
        return f.read()

setup(
    name='htmltopdfy',
    version='1.0.0',
    description='Convert template html to pdf',
    long_description=readme(),
    long_description_content_type='text/markdown',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
    ],
    url='https://github.com/VolkenoMakers/htmlToPdf',  # the URL of your package's home page e.g. github link
    author='VOLKENO',
    author_email='contact@volkeno-tank.com',
    keywords='core package', # used when people are searching for a module, keywords separated with a space
    license='MIT', # note the American spelling
    packages=['htmltopdfy'],
    install_requires=find_packages(), # a list of other Python modules which this module depends on.  For example RPi.GPIO
    include_package_data=True,
    zip_safe=False
)



def __init__(self,media_root_url,file_name,template_src,context_dict):
  
    self.file_name = file_name #It's file name 
    self.media_root_url = media_root_url #Tt's your settings.media_root
    self.template_src = template_src #It's your template name
    self.context_dict = context_dict # Optionnel[It's variable or variables who is linked with template]

